/***************************************************************************
 $RCSfile$
                             -------------------
    cvs         : $Id$
    begin       : Mon Mar 01 2004
    copyright   : (C) 2004 by Martin Preuss
    email       : martin@libchipcard.de

 ***************************************************************************
 *          Please see toplevel file COPYING for license details           *
 ***************************************************************************/


#ifndef CHIPCARD_SERVER_USBRAWSCANNER_L_H
#define CHIPCARD_SERVER_USBRAWSCANNER_L_H

#include "devmonitor.h"


LC_DEVSCANNER *LC_UsbRawScanner_new();





#endif /* CHIPCARD_SERVER_USBRAWSCANNER_L_H */
